Width

Enum Width 

pub enum Width {
    D32,
    D64,
    D128,
}
One of the three decimal interchange formats.

Variants



D32

_Decimal32, seven digits.



D64

_Decimal64, sixteen digits.



D128

_Decimal128, thirty four digits.

Implementations

Source

impl Width

pub const fn bits(self) -> u32

The size of the encoding in bits.

pub const fn digits(self) -> u32

The most decimal digits a coefficient has, IEEE’s p.

pub const fn bias(self) -> i32

What is added to the exponent to store it, which makes the smallest exponent zero.

pub const fn min_exponent(self) -> i32

The smallest exponent q a coefficient can have.

pub const fn max_exponent(self) -> i32

The largest exponent q a coefficient can have, IEEE’s emax - p + 1.

pub const fn max_coefficient(self) -> u128

The largest coefficient, 10^p - 1.