pub enum Width {
D32,
D64,
D128,
}Expand description
One of the three decimal interchange formats.
Variants
Implementations
Sourceimpl Width
impl Width
Sourcepub const fn bias(self) -> i32
pub const fn bias(self) -> i32
What is added to the exponent to store it, which makes the smallest exponent zero.
Sourcepub const fn min_exponent(self) -> i32
pub const fn min_exponent(self) -> i32
The smallest exponent q a coefficient can have.
Sourcepub const fn max_exponent(self) -> i32
pub const fn max_exponent(self) -> i32
The largest exponent q a coefficient can have, IEEE’s emax - p + 1.
Sourcepub const fn max_coefficient(self) -> u128
pub const fn max_coefficient(self) -> u128
The largest coefficient, 10^p - 1.